@@ -38,6 +38,8 @@
 #include "vararray.hpp"
 #include "string_list.hpp"
 
+#include "gettext.h"
+
 //#include "iostream.hpp"
 
 #define DEFAULT_LANG "en_US"
@@ -846,8 +848,7 @@ namespace acommon {
       default:
         ;
       }
-      entry->value.ensure_null_end();
-      if (do_unescape) unescape(entry->value.data());
+      if (do_unescape) unescape(entry->value.mstr());
 
       entry->next = *insert_point_;
       *insert_point_ = entry;
