@@ -4,16 +4,18 @@
 // license along with this library if you did not you can find
 // it at http://www.gnu.org/.
 
-#include <stdint.h>
+#include "settings.h"
 
+#include "indiv_filter.hpp"
 #include "convert.hpp"
 #include "config.hpp"
 #include "indiv_filter.hpp"
 #include "mutable_container.hpp"
 #include "copy_ptr-t.hpp"
-#include "loadable-filter-API.hpp"
 
-namespace acommon {
+namespace {
+
+  using namespace acommon;
 
   class EmailFilter : public IndividualFilter 
   {
@@ -24,23 +26,24 @@ namespace acommon {
 
     class QuoteChars : public MutableContainer {
     public:
-      Vector<uint32_t> data;
+      typedef FilterChar::Chr Value;
+      Vector<Value> data;
       Conv conv;
-      bool have(uint32_t c) {
-        uint32_t * i = data.pbegin();
-        uint32_t * end = data.pend();
+      bool have(Value c) {
+        Value * i = data.pbegin();
+        Value * end = data.pend();
         for (; i != end && *i != c; ++i);
         return i != end;
       }
-      PosibErr<bool> add(ParmString s) {
-        uint32_t c = *(uint32_t *)conv(s);
+      PosibErr<bool> add(ParmStr s) {
+        Value c = *(Value *)conv(s);
         if (!have(c)) data.push_back(c);
         return true;
       }
-      PosibErr<bool> remove(ParmString s) {
-        uint32_t c = *(uint32_t *)conv(s);
-        Vector<uint32_t>::iterator i = data.begin();
-        Vector<uint32_t>::iterator end = data.end();
+      PosibErr<bool> remove(ParmStr s) {
+        Value c = *(Value *)conv(s);
+        Vector<Value>::iterator i = data.begin();
+        Vector<Value>::iterator end = data.end();
         for (; i != end && *i != c; ++i);
         if (i != end) data.erase(i);
         return true;
@@ -62,9 +65,9 @@ namespace acommon {
   {
     name_ = "email-filter";
     order_num_ = 0.85;
-    is_quote_char.conv.setup(*opts, "utf-8", "utf-32");
-    opts->retrieve_list("filter-email-quote", &is_quote_char);
-    margin = opts->retrieve_int("filter-email-margin");
+    is_quote_char.conv.setup(*opts, "utf-8", "ucs-4", NormNone);
+    opts->retrieve_list("f-email-quote", &is_quote_char);
+    margin = opts->retrieve_int("f-email-margin");
     reset();
     return true;
   }
@@ -103,7 +106,11 @@ namespace acommon {
       for (FilterChar * i = line_begin; i != cur; ++i)
 	*i = ' ';
   }
-  
-ACTIVATE_FILTER(acommon,EmailFilter,email);
 }
 
+C_EXPORT 
+IndividualFilter * new_aspell_email_filter() {
+  return new EmailFilter;                                
+}
+
+
