@@ -18,11 +18,12 @@
 //#define FILTER_PROGRESS_CONTROL "tex-filter-debug.log"
 //#include "filter_debug.hpp"
 //#include <stdio.h>
-#include <cstdio>
+//#include <cstdio>
 #include "filter_char_vector.hpp"
 #include "string_list.hpp"
 #include "string_enumeration.hpp"
 
+#include "gettext.h"
 
 namespace {
 
