@@ -45,7 +45,7 @@
 #include <cstring>
 #include <cstdio>
 
-#include "iostream.hpp"
+//#include "iostream.hpp"
 
 #include "affix.hpp"
 #include "errors.hpp"
@@ -57,6 +57,8 @@
 #include "lsort.hpp"
 #include "hash-t.hpp"
 
+#include "gettext.h"
+
 using namespace std;
 
 namespace aspeller {
@@ -1248,7 +1250,7 @@ bool SfxEntry::check(const LookupInfo & linf, ParmString word,
       CheckInfo * lci = 0;
       tmpl += stripl;
       const SensitiveCompare * cmp = 
-        optflags & XPRODUCT ? &linf.sp->s_cmp_middle : &linf.sp->s_cmp_end;
+        optflags & XPRODUCT ? &linf.sp->s_cmp_middle : &linf.sp->s_cmp_begin;
       int res = linf.lookup(tmpword, cmp, achar, wordinfo, gi);
       if (res == 1
           && ((optflags & XPRODUCT) == 0 || TESTAFF(wordinfo.aff, ep->achar)))
