@@ -18,6 +18,10 @@
 
 #include "settings.h"
 
+#ifdef DEFINE_XOPEN_SOURCE_EXTENDED
+#  define _XOPEN_SOURCE_EXTENDED 1
+#endif
+
 #ifdef CURSES_NON_POSIX
 #define CURSES_ONLY 1
 #endif
@@ -29,6 +33,8 @@
 #include "convert.hpp"
 #include "config.hpp"
 
+#include "gettext.h"
+
 using namespace acommon;
 
 StackPtr<CheckerString> state;
